@@ -20,8 +20,8 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_PIM_NOTES_SEARCHSTORE_H
-#define AKONADI_SEARCH_PIM_NOTES_SEARCHSTORE_H
+#ifndef AKONADI_SEARCH_PIM_NOTE_SEARCHSTORE_H
+#define AKONADI_SEARCH_PIM_NOTE_SEARCHSTORE_H
 
 #include "../pimsearchstore.h"
 
@@ -45,4 +45,4 @@ public:
 
 }
 }
-#endif // AKONADI_SEARCH_PIM_NOTES_SEARCHSTORE_H
+#endif // AKONADI_SEARCH_PIM_NOTE_SEARCHSTORE_H
